# Chatwoot Client for Python

`chatwoot-client` is a simple Chatwoot API wrapper for Python.

It provides an easy-to-use interface for interacting with the Chatwoot API, allowing you to perform various actions such as creating, retrieving, updating, and deleting conversations, messages, and more.

## Installation

To install, simply run:

```
pip install chatwoot-client
```

## Usage

(TO BE ADDED)

## Resources

(TO BE ADDED)

## Example

(TO BE ADDED)

## Credits

Project is influenced by and borrowed from [woot](https://github.com/dearkafka/woot) and in fact started by using it as it is, but it didn't have support for Python 3.11 and VSCode didn't recognize resources and endpoints. So I made it with a straightforward approach without using dynamic attributes.

## License

The project is licensed under the Cooperative Non-Violent Public License v7 or later (CNPLv7+) - see the [LICENSE](LICENSE) for details. Built for people, not corporations.
